.. OpenMesh Python Bindings documentation master file, created by
   sphinx-quickstart on Mon Feb 12 17:49:06 2018.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Welcome to OpenMesh Python Bindings's documentation!
====================================================

Contents:

.. toctree::
   :maxdepth: 2
   :caption: Tutorial

   install
   firststeps
   iterators
   properties
   indexarrays
   garbagecollection
   readwrite


.. toctree::
   :maxdepth: 2
   :caption: Advanced Topics

   datastructure


.. toctree::
   :maxdepth: 2
   :caption: Class Reference

   trimesh
   polymesh


Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
